local mod = ...



-- Node: Wait for Opponent --------------------------------------------------------------------------------------------------------
mod:registerBehaviorTreeNode({
    Name = "BEHAVIOR_NODE_ENTERTAINMENT_FIGHTER_WAIT",
    VariableList = {
		AgentData = "BEHAVIOR_TREE_DATA_AGENT",
    },

    Update = function(self, instance)

        local compAgent = nil
        compAgent = self.AgentData.Agent

        local posAgent = nil
        posAgent = compAgent:getOwner():getGlobalPosition()

        local found = nil

        local listVill = compAgent:getLevel():getComponentManager("COMP_VILLAGER"):getAllEnabledComponent():forEach(function(compVill)

            local assetJob = nil
            assetJob = compVill:getAssetJob()
            if assetJob then
                if assetJob.JobName == "JOB_ENTERTAINMENT_FIGHTER_NAME" then

                    local posVill = nil
                    local dist = nil

                    posVill = compVill:getOwner():getGlobalPosition()
                    dist = math.sqrt( (posVill[1] - posAgent[1])^2 + (posVill[3] - posAgent[3])^2 )

                    if dist > 0 and dist <= 3 then
                        found = true
                    end
                end
            end

        end)

        if found then
            return BEHAVIOR_TREE_NODE_RESULT.TRUE

        else
            compAgent:setAnimation("IDLE")
            return BEHAVIOR_TREE_NODE_RESULT.FALSE

        end

    end -- update

})



-- Behavior Tree -------------------------------------------------------------------------------------
mod:registerBehaviorTree({
	Id = "BEHAVIOR_ENTERTAINMENT_FIGHTER",
	VariableList = {
		{
			Name = "AgentData",
			DataType = "BEHAVIOR_TREE_DATA_AGENT",
			IsPublic = true,
			InitialValue = {},
		},
		{
			Name = "DoJobTimer",
			DataType = "BEHAVIOR_TREE_DATA_WAIT",
			IsPublic = false,
			InitialValue = {
				TimeToWait = 0,
				Animation = AGENT_ANIMATION.HAND_ATTACK,
				SetIdleAfterWait = false,
			},
		},
		{
			Name = "WorkplacePosition",
			DataType = "BEHAVIOR_TREE_DATA_LOCATION",
			IsPublic = false,
			InitialValue = {
				CanNavigateOnGround = true,
				CanNavigateOnWater = false,
				IsSetOrientationOnDestination = true,
			},
		},
		{
			Name = "ResourceProducedList",
			DataType = "BEHAVIOR_TREE_DATA_RESOURCE_PRODUCTION",
			IsPublic = false,
		},
        {
			Name = "ShouldReceiveXp",
			DataType = "BEHAVIOR_TREE_DATA_BOOL",
			IsPublic = false,
			InitialValue = {
				Value = false,
			},
		},
        {
			Name = "UseWorkstationAnim",
			DataType = "BEHAVIOR_TREE_DATA_BOOL",
			IsPublic = false,
			InitialValue = {
				Value = false,
			},
		},
		{
			Name = "WorkLoop",
			DataType = "BEHAVIOR_TREE_DATA_LOOP",
			IsPublic = true,
			InitialValue = {
				LoopCount = 10,
				Duration = 0.0,
				IsInfinite = false,
				IsDuration = false,
			},
		},
	},
	Root = {
		Name = "WorkingGlobalSequencer",
		Type = "SEQUENCER",
		Children = {
			{
				Name = "WorkLoopRepeater",
				Type = "REPEAT",
				RepeatData = "WorkLoop",
				Child = {
					Name = "WorkLoopSequencer",
					Type = "SEQUENCER",
					Children = {
						{
							Name = "SetupWork",
							Type = "SETUP_WORK",
							AgentData = "AgentData",
							TimeToWait = "DoJobTimer",
							WorkPosition = "WorkplacePosition",
						},
						{
							Name = "GoToWorkplace",
							Type = "GO_TO",
							AgentData = "AgentData",
							Destination = "WorkplacePosition",
							BuildingPathType = "",
							AnimationData = "",
							AnimationSpeedMultiplier = "",
						},
                        {
                            Name = "WaitForOpponent",
                            Type = "BEHAVIOR_NODE_ENTERTAINMENT_FIGHTER_WAIT",
                            AgentData = "AgentData",
                        },
						{
							Name = "ProduceResource",
							Type = "PRODUCE_RESOURCE",
							AgentData = "AgentData",
							TimeToWait = "DoJobTimer",
							ResourceProducedList = "ResourceProducedList",
                            OptionalUseWorkstationAnim = "UseWorkstationAnim",
						},
						{
							Name = "GiveXp",
							Type = "GIVE_JOB_XP",
							AgentData = "AgentData",
							ShouldReceiveXp = "",
						},
					},
				},
			},
		},
	},
})

